import { Guides } from '@/components/documentation/Guides'
import { ApiDocs } from '@/components/documentation/ApiDocs'
import { HeroPattern } from '@/components/documentation/HeroPattern'

export const description =
  '欢迎来到 Robyn API 文档。您将找到全面的指南和文档，帮助您尽快开始使用 Robyn，并在遇到困难时获得支持。'

export const sections = [
  { title: '应用示例', id: 'guides' },
  { title: 'API 参考', id: 'api_docs' },
]

<HeroPattern />

<div className="text-white">
# API文档
欢迎来到 Robyn API 文档。您将找到全面的指南和文档，帮助您尽快开始使用 Robyn，并在遇到困难时获得支持。

<div className="not-prose mb-16 mt-6 flex gap-3">
  <Button href="/documentation/zh/example_app" arrow="right" children="应用示例" />
  <Button href="/documentation/zh/api_reference" variant="outline" children="API 文档" />
</div>

## 入门指南 {{ anchor: false }}

示例应用是一个简单的 Web 应用程序，展示了如何使用 Robyn API。如果您是 Robyn 的新手，这是一个很好的起点。

API 参考包含了有关 Robyn API 的详细信息。如果您已经熟悉 Robyn 并想了解更多关于 API 的信息，这是一个很好的起点。

</div>
<Guides />

<ApiDocs /> 
